=======
Support
=======

If you encounter any bugs or issues that have not been reported yet,
please open an issue on Github_.

For any other questions or inquiries, feel free to reach out to the
project developers:

* Tomer Burg (tomerburg@gmail.com)
* Sam Lillo (splillo@gmail.com)

.. _Github: https://github.com/tropycal/tropycal/issues
